import pkg_resources

from .core import Combine


__author__ = "Dropseed"
__email__ = "python@dropseed.dev"
__version__ = pkg_resources.get_distribution("combine").version
